@@ -1,7 +1,8 @@
 package Math::Counting;
+our $AUTHORITY = 'cpan:GENE';
 # ABSTRACT: Combinatorial counting operations
 
-our $VERSION = '0.1304';
+our $VERSION = '0.1305';
 
 use strict;
 use warnings;
@@ -128,7 +129,7 @@ Math::Counting - Combinatorial counting operations
 
 =head1 VERSION
 
-version 0.1304
+version 0.1305
 
 =head1 SYNOPSIS
 
@@ -146,11 +147,11 @@ Engineering
 
 =head1 DESCRIPTION
 
-Compute the factorial, number of permutations and number of combinations.
+Compute the factorial, number of permutations, number of derangements and number
+of combinations.
 
 The C<:big> functions are wrappers around L<Math::BigInt/bfac> with a bit of
-arithmetic between.  Also the C<bperm> function accepts an additional boolean to
-indicate repetition.
+arithmetic between.
 
 The student versions exist to illustrate the computation "in the raw" as it were.
 To see these computations in action, Use The Source, Luke.
@@ -186,8 +187,8 @@ from a set of B<n> elements, using the "student" version.
 
 Return the computations:
 
-  n^k           # with repetition
-  n! / (n-k)!   # without repetition
+  n^k           # with repetition $r == 1
+  n! / (n-k)!   # without repetition $r == 0
 
 =head2 bderange()
 
@@ -213,19 +214,19 @@ This is algorithm expresses the "student" version.
 
 Return the combination computations:
 
-  (n+k-1)! / k!(n-1)!   # with repetition
-  n! / k!(n-k)!         # without repetition
+  (n+k-1)! / k!(n-1)!   # with repetition $r == 1
+  n! / k!(n-k)!         # without repetition $r == 0
 
 =head1 TO DO
 
-Allow specification of the math processor to use.
-
 Provide the gamma function for the factorial of non-integer numbers?
 
 =head1 SEE ALSO
 
 L<Math::BigInt/bfac>
 
+L<Math::BigFloat>
+
 B<Higher Order Perl> by Mark Jason Dominus
 (L<http://hop.perl.plover.com>).
 
@@ -274,7 +275,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gene Boggs.
+This software is copyright (c) 2015 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
